/*
 * Project name:
     TWI_Simple (Simple test of Twi library routines)
 * Copyright:
     (c) MikroElektronika, 2008.
 * Revision History:
     20080930:
       - initial release;
 * Description:
     This programme demonstrates usage of the Twi library routines.
     It establishes TWI bus communication with 24C02 EEPROM chip, writes one byte
     of data on some location, then reads it and displays it on PORTA.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/eng/products/view/321/easyavr6-development-system/
     Oscillator:      External, 8.0000 MHz
     Ext. Modules:    EEPROM extra board - ac:EEPROM
                      http://www.mikroe.com/eng/products/view/137/eeprom-board/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - Connect EEPROM extra board on PORTC.
     - Pull-up TWI communication lines (RC0 and RC1) and turn off PORTC LEDs.
     - Turn on PORTA LEDs (board specific).
*/

void main(){
  DDRA = 0xFF;              // configure PORTA as output

  TWI_Init(100000);         // initialize TWI communication
  TWI_Start();              // issue TWI start signal
  TWI_Write(0xA2);          // send byte via TWI (device address + W)
  TWI_Write(2);             // send byte (address of EEPROM location)
  TWI_Write(0xAA);          // send data (data to be written)
  TWI_Stop();               // issue TWI stop signal

  Delay_100ms();

  TWI_Start();              // issue TWI start signal
  TWI_Write(0xA2);          // send byte via TWI (device address + W)
  TWI_Write(2);             // send byte (data address)
  TWI_Start();              // issue TWI signal repeated start
  TWI_Write(0xA3);          // send byte (device address + R)
  PORTA = TWI_Read(0u);     // read data (NO acknowledge)
  TWI_Stop();               // issue TWI stop signal
}